chrome.runtime.onMessage.addListener(function(request, sender, sendResponse) {
  if (request.action === "saveText") {
      try {
          console.log("Content script received 'saveText' action.");

          // 1) Find the chat content container
          //    The original code targeted a more specific element,
          //    but let's keep it flexible with a fallback to <main>.
          var chatContentElement = document.querySelector("#__next main") || document.querySelector("main");
          var chatTitleElement   = document.querySelector("main h1") || document.querySelector("h1");

          // Validate existence of main chat area
          if (!chatContentElement) {
              console.error("Chat content not found.");
              sendResponse({ status: "error", message: "Chat content not found." });
              return;
          }

          // 2) Extract chat name (if <h1> not found, default)
          var chatTitle = chatTitleElement
              ? chatTitleElement.innerText.trim()
              : "ChatGPT_Chat";

          // Remove invalid filename characters
          chatTitle = chatTitle.replace(/[/\\?%*:|"<>]/g, '_');

          // 3) Extract the main text of the chat
          var chatText = chatContentElement.innerText.trim();
          if (!chatText) {
              console.error("Chat text is empty or not found.");
              sendResponse({ status: "error", message: "No chat text to save." });
              return;
          }

          // 4) Create a timestamp
          const now = new Date();
          const timestamp = now.toISOString().replace(/[:\-]|\.\d{3}/g, '');

          // 5) Build filename
          const filename = `${chatTitle}_ChatGPT_${timestamp}.txt`;
          console.log("Filename:", filename);

          // 6) Create a blob and use an anchor for download
          var blob = new Blob([chatText], { type: "text/plain" });
          var url = URL.createObjectURL(blob);

          var a = document.createElement('a');
          a.href = url;
          a.download = filename;
          // The anchor must be in the DOM for click to work
          document.body.appendChild(a);
          a.click();
          // Cleanup
          document.body.removeChild(a);
          URL.revokeObjectURL(url);

          // 7) Success response
          sendResponse({ status: "success" });
      } catch (error) {
          console.error("Error saving chat:", error);
          sendResponse({ status: "error", message: error.message });
      }
  }
});



