// Final script.js without debug logs

window.SpeechRecognition = window.SpeechRecognition || window.webkitSpeechRecognition;

if (!window.SpeechRecognition) {
    alert("Speech recognition is not supported in this browser. Please use Chrome.");
} else {
    let recognition = new SpeechRecognition();
    recognition.continuous = true;
    recognition.interimResults = false;  // Only final results
    recognition.lang = "en-US";

    let output = document.getElementById("output");
    let isListening = false;
    let transcriptSoFar = "";

    // Helper to update the textarea with the transcript only
    function updateOutput() {
        output.value = transcriptSoFar;
    }

    document.getElementById("start").addEventListener("click", () => {
        if (!isListening) {
            recognition.start();
            isListening = true;
            console.log("Speech recognition started...");
        }
    });

    document.getElementById("stop").addEventListener("click", () => {
        recognition.stop();
        isListening = false;
        console.log("Speech recognition stopped.");
    });

    recognition.onresult = (event) => {
        let newTranscript = "";
        for (let i = event.resultIndex; i < event.results.length; i++) {
            let result = event.results[i];
            if (result.isFinal) {
                newTranscript += result[0].transcript + " ";
            }
        }
        if (newTranscript.trim() !== "") {
            transcriptSoFar += newTranscript;
        }
        updateOutput();
    };

    recognition.onerror = (event) => {
        console.error("Speech recognition error: " + event.error);
        alert("Speech recognition error: " + event.error);
    };

    recognition.onend = () => {
        if (isListening) {
            recognition.start();
        }
    };

    document.getElementById("clear").addEventListener("click", () => {
        transcriptSoFar = "";
        updateOutput();
    });

    document.getElementById("save").addEventListener("click", () => {
        let now = new Date();
        let timestamp = now.toISOString().replace(/[-:T]/g, "").split(".")[0];
        let inputName = document.getElementById("filenameInput").value.trim();
        let prefix = inputName ? inputName.replace(/\s+/g, "_") : "Transcript_ATH";
        let filename = `${prefix}_${timestamp}.txt`;
        let blob = new Blob([transcriptSoFar], { type: "text/plain" });
        let url = URL.createObjectURL(blob);
        chrome.downloads.download({
            url: url,
            filename: filename
        });
    });

    document.getElementById("selectAll").addEventListener("click", () => {
        output.select();
        document.execCommand("copy");
        alert("Text copied to clipboard!");
    });
}
